diff --git a/tests/ubi-tests/io_paral.c b/tests/ubi-tests/io_paral.c
index 4040b3e..2dc43e1 100644
--- a/tests/ubi-tests/io_paral.c
+++ b/tests/ubi-tests/io_paral.c
@@ -50,9 +50,62 @@ static char vol_nodes[THREADS_NUM + 1][sizeof(UBI_VOLUME_PATTERN) + 99];
 static unsigned char *wbufs[THREADS_NUM + 1];
 static unsigned char *rbufs[THREADS_NUM + 1];
 
+
+static void printhex(const void* data, size_t size) {
+	char ascii[17];
+	size_t i, j;
+	ascii[16] = '\0';
+
+	printf("\n");
+
+	for (i = 0; i < size; ++i) {
+		printf("%02X ", ((unsigned char*)data)[i]);
+		if (((unsigned char*)data)[i] >= ' ' && ((unsigned char*)data)[i] <= '~') {
+			ascii[i % 16] = ((unsigned char*)data)[i];
+		} else {
+			ascii[i % 16] = '.';
+		}
+		if ((i+1) % 8 == 0 || i+1 == size) {
+			printf(" ");
+			if ((i+1) % 16 == 0) {
+				printf("|  %s \n", ascii);
+			} else if (i+1 == size) {
+				ascii[(i+1) % 16] = '\0';
+				if ((i+1) % 16 <= 8) {
+					printf(" ");
+				}
+				for (j = (i+1) % 16; j < 16; ++j) {
+					printf("   ");
+				}
+				printf("|  %s \n", ascii);
+			}
+		}
+	}
+	printf("\n");
+}
+
+static long my_memcmp(const void *Ptr1, const void *Ptr2, size_t Count)
+{
+    int v = 0;
+    long pos = 0;
+    char *p1 = (char *)Ptr1;
+    char *p2 = (char *)Ptr2;
+
+    while(Count-- > 0 && v == 0)
+    {
+        v = *(p1++) - *(p2++);
+        if (v == 0)
+            pos++;
+        else
+            break;
+    }
+
+    return pos;
+}
+
 static int update_volume(int vol_id, int bytes)
 {
-	int i, fd, ret, written = 0, rd = 0;
+	int i, fd, ret, written = 0, rd = 0, pos;
 	char *vol_node = vol_nodes[vol_id];
 	unsigned char *wbuf = wbufs[vol_id];
 	unsigned char *rbuf = rbufs[vol_id];
@@ -123,7 +176,17 @@ static int update_volume(int vol_id, int bytes)
 	}
 
 	if (memcmp(wbuf, rbuf, bytes)) {
-		errorm("written and read data are different");
+		pos = my_memcmp(wbuf, rbuf, bytes);
+		errorm("written and read data are different at byte: %d\n", pos);
+
+		errorm("Wbuf:");
+
+		if (pos <= 10) //Try to print 10 bytes before mismatch
+			pos = 10;
+		printhex(&wbuf[pos-10], 8192);
+
+		errorm("Rbuf:");
+		printhex(&rbuf[pos-10], 8192);
 		goto err_close;
 	}
 
@@ -170,7 +233,7 @@ static void *update_thread(void *ptr)
 
 static void *write_thread(void *ptr)
 {
-	int ret, fd, vol_id = (long)ptr, i;
+	int ret, fd, vol_id = (long)ptr, i, pos;
 	char *vol_node = vol_nodes[vol_id];
 	unsigned char *wbuf = wbufs[vol_id];
 	unsigned char *rbuf = rbufs[vol_id];
@@ -223,7 +286,17 @@ static void *write_thread(void *ptr)
 		}
 
 		if (memcmp(wbuf, rbuf, dev_info.leb_size)) {
-			errorm("written and read data are different");
+			pos = my_memcmp(wbuf, rbuf, dev_info.leb_size);
+			errorm("written and read data are different at byte: %d\n", pos);
+
+			errorm("Wbuf:");
+
+			if (pos <= 10) //Try to print 10 bytes before mismatch
+				pos = 10;
+			printhex(&wbuf[pos-10], 8192);
+
+			errorm("Rbuf:");
+			printhex(&rbuf[pos-10], 8192);
 			break;
 		}
 	}
